/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;

/**
 * An animated bar.
 * 
 * @author Michael Hedenus
 */
public class Animation extends BufferedCanvas
{
	private static final long serialVersionUID = -82663161936816680L;
	private Dimension preferredSize;

	public Animation()
	{
		preferredSize = new Dimension(16 * 16, 16);

		setBackground(UILayout.getInstance().getColor("default.background"));
		setForeground(UILayout.getInstance().getColor("default.foreground"));
		setFont(UILayout.getInstance().getFont("default.font"));
	}

	private transient int d = 16;
	private transient int n;
	private transient int phase;
	private transient Color[] colors;

	public void paintBuffer(Graphics g)
	{
		if (animator == null)
		{
			animator = new Animator();
			animator.start();
		}
		int width = getWidth();
		int height = getHeight();

		g.setColor(getBackground());
		g.fillRect(0, 0, width, height);

		int w = preferredSize.width;
		int h = preferredSize.height;
		int x0 = (width - w) / 2;
		int y0 = (height - h) / 2;
		
		if (isAnimated())
		{
			if (colors == null)
			{
				n = Math.max(w / d, 1);
				colors = new Color[n];
				for (int i = 0; i < n; i++)
				{
					int r = 255 - ((int)(255.0 * Math.sin(((i + 1) * Math.PI / n))) & 0xFF);
					colors[i] = new Color(255, r, r);
				}
			}

			for (int i = 0; i < n; i++)
			{
				int j = ((n - 1 - i + phase) % n);
				g.setColor(colors[j]);
				g.fillRect(x0 + d * i, y0, d, h);
			}

			phase = ((phase + 1) % n);
		}
		
		g.setColor(getForeground());
		g.drawRect(x0, y0, w, h);
	}

	public Dimension getPreferredSize()
	{
		return preferredSize;
	}

	private boolean animated = false;
	private Animator animator;

	public boolean isAnimated()
	{
		return animated;
	}

	public void setAnimated(boolean animated)
	{
		this.animated = animated;
		if (animator != null)
		{
			synchronized (animator)
			{
				animator.notifyAll();
			}
		}
	}

	private class Animator extends Thread
	{
		private boolean finish = false;

		public void run()
		{
			while (!finish)
			{
				try
				{
					synchronized (this)
					{
						while (!isAnimated())
						{
							this.wait();
						}
					}

					Thread.sleep(1000 / 16);
				}
				catch (InterruptedException e)
				{
					e.printStackTrace();
				}

				Animation.this.repaint();
			}
		}
	}
}
