/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.awt.Canvas;
import java.awt.Dimension;
import java.awt.Graphics;

/**
 * A bar displaying a value.
 * 
 * @author Michael Hedenus
 */
public class Bar extends Canvas
{
	private static final long serialVersionUID = 6878776100875095602L;

	private int minValue;
	private int maxValue;
	private int value;

	public Bar(int value, int minValue, int maxValue)
	{
		this.minValue = minValue;
		this.maxValue = maxValue;
		this.value = value;

		setBackground(UILayout.getInstance().getColor("Bar.background"));
		setForeground(UILayout.getInstance().getColor("Bar.foreground"));
	}
	
	public Dimension getPreferredSize()
	{
		return new Dimension(640,32);
	}

	public void paint(Graphics g)
	{
		int width = getWidth();
		int height = getHeight();

		int x = (width * (value - minValue)) / (maxValue - minValue);
		if (x < 0)
		{
			x = 0;
		}
		if (x > width)
		{
			x = width;
		}

		g.setColor(getForeground());
		g.fillRect(0, 0, x, height);

		g.setColor(getBackground());
		g.fillRect(x, 0, width - x, height);
	}

	public int getMaxValue()
	{
		return maxValue;
	}

	public void setMaxValue(int maxValue)
	{
		this.maxValue = maxValue;
	}

	public int getMinValue()
	{
		return minValue;
	}

	public void setMinValue(int minValue)
	{
		this.minValue = minValue;
	}

	public int getValue()
	{
		return value;
	}

	public void setValue(int value)
	{
		this.value = value;
	}

	public void reset()
	{
		setValue(minValue);
	}
}
