/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.awt.Canvas;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.GraphicsConfiguration;
import java.awt.GraphicsEnvironment;
import java.awt.Rectangle;
import java.awt.image.BufferedImage;

/**
 * A double-buffered canvas.
 * 
 * @author Michael Hedenus
 */
public abstract class BufferedCanvas extends Canvas
{
	private static final long serialVersionUID = -1524579868197137870L;
	private BufferedImage offscreenImage;
	private Graphics2D offscreenGraphics;
	private Rectangle parentClip = new Rectangle();

	public void update(Graphics g)
	{
		paint(g);
	}

	public void paint(Graphics g)
	{
		int w = this.getWidth();
		int h = this.getHeight();

		if (offscreenImage == null || offscreenImage.getWidth() != w || offscreenImage.getHeight() != h)
		{	
			GraphicsConfiguration graphicsConfiguration = getGraphicsConfiguration();
			if (graphicsConfiguration == null)
			{
				GraphicsEnvironment graphicsEnvironment = GraphicsEnvironment.getLocalGraphicsEnvironment();
				graphicsConfiguration = graphicsEnvironment.getDefaultScreenDevice().getDefaultConfiguration();
			}

			offscreenImage = graphicsConfiguration.createCompatibleImage(w, h);
			if (offscreenImage != null)
			{
				offscreenGraphics = offscreenImage.createGraphics();
				if (offscreenGraphics != null)
				{
					System.out.println("BufferedCanvas: new offscreen: " + w + "x" + h);
				}
				else
				{
					System.err.println("BufferCanvas: no graphics");
				}
			}
			else
			{
				System.err.println("BufferCanvas: no image");
			}
		}

		if (offscreenGraphics != null && offscreenImage != null)
		{
			parentClip.x = 0;
			parentClip.y = 0;
			parentClip.width = w;
			parentClip.height = h;
			parentClip = g.getClipBounds(parentClip);
			offscreenGraphics.setClip(parentClip.x, parentClip.y, parentClip.width, parentClip.height);

			paintBuffer(offscreenGraphics);

			//getToolkit().sync();
			g.drawImage(offscreenImage, 0, 0, this);
		}
		else
		{
			paintBuffer(g);
		}
	}

	public abstract void paintBuffer(Graphics g);
}
