/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;

import de.hedenus.util.Properties;

/**
 * Simple preferences API. Preferences are stored in the "user.home" folder.
 * 
 * @author Michael Hedenus
 */
public class Preferences extends Properties
{
	private static final long serialVersionUID = -7076708603316013283L;

	private final File file;

	public Preferences(String propertiesName)
	{
		file = new File(System.getProperty("user.home"), propertiesName);
	}
	
	public void open() throws IOException
	{
		if (file.exists())
		{
			FileInputStream inStream = null;
			try
			{
				inStream = new FileInputStream(file);
				this.load(inStream);
			}
			finally
			{
				if (inStream != null)
				{
					inStream.close();
				}
			}
		}
	}

	public void close() throws IOException
	{
		FileOutputStream outStream = null;
		try
		{
			outStream = new FileOutputStream(file);
			this.store(outStream, "Instance of "+getClass().getName());
			outStream.flush();
		}
		finally
		{
			if (outStream != null)
			{
				outStream.close();
			}
		}
	}
}
