/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.io.FilterInputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * An input stream that notifies a <code>ProgressListener</code>.
 * 
 * @author Michael Hedenus
 */
public class ProgressInputStream extends FilterInputStream
{
	private final ProgressListener progressListener;
	private final int bytesAvailable;
	private boolean start = false;
	private int bytesRead = 0;
	
	public ProgressInputStream(InputStream in, int contentLength, ProgressListener progressListener)
	{
		super(in);
		this.bytesAvailable = contentLength;
		this.progressListener = progressListener;
	}

	public ProgressListener getProgressListener()
	{
		return progressListener;
	}

	public int read() throws IOException
	{
		int r = in.read();
		if(r!=(-1))
		{
			fireProgressUpdate(1);
		}
		return r;
	}

	public int read(byte b[], int off, int len) throws IOException
	{
		int r = in.read(b, off, len);
		fireProgressUpdate(r);
		return r;
	}

	public void close() throws IOException
	{
		in.close();
		progressListener.progressEnd();
	}

	private void fireProgressUpdate(int r) throws IOException
	{
		if (!start)
		{
			start = true;
			progressListener.progressStart();
		}

		if (r > 0)
		{
			bytesRead += r;
			progressListener.progressUpdate(bytesRead, 0, bytesAvailable);
		}
	}
}
