/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Label;

/**
 * A monitor which receives notifications and displays from a process.
 * This is the default implementation of <code>ProgressListener</code>.
 * 
 * @author Michael Hedenus
 */
public class ProgressMonitor extends Container implements ProgressListener
{
	private static final long serialVersionUID = 8805254216235302034L;

	private Bar bar;
	private Label label;
	private int increment = 10;

	public ProgressMonitor()
	{
		setLayout(new BorderLayout());
		bar = new Bar(0, 0, 100);
		label = new Label("", Label.CENTER);
		label.setBackground(UILayout.getInstance().getColor("default.background"));
		this.add(bar, BorderLayout.NORTH);
		this.add(label, BorderLayout.CENTER);
	}
	
	public void setText(String text)
	{
		label.setText(text);
	}

	public synchronized void progressUpdate(int value, int minValue, int maxValue)
	{
		int oldValue = bar.getValue();
		int newValue = (100 * (value - minValue)) / (maxValue - minValue);

		if (newValue >= (oldValue + increment))
		{
			bar.setValue(newValue);
			bar.repaint();
		}
	}

	public void progressStart()
	{
		bar.reset();
	}

	public int getIncrement()
	{
		return increment;
	}

	public void setIncrement(int increment)
	{
		this.increment = increment;
	}

	public void progressEnd()
	{
		//NOP
	}
}
