/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.util.Comparator;

/**
 * A comparator for strings.
 * 
 * @author Michael Hedenus
 */
public class StringSearcher implements Comparator
{
	/**
	 * Compares objects and/or strings according to the <code>toString(Object)</code> implementation ignoring case.
	 */
	public int compare(Object obj1, Object obj2)
	{
		String s1 = obj1 instanceof String ? (String)obj1 : this.toString(obj1);
		String s2 = obj2 instanceof String ? (String)obj2 : this.toString(obj2);
		return s1.compareToIgnoreCase(s2);
	}
	
	/**
	 * Used to generate string representation.
	 */
	public String toString(Object item)
	{
		return String.valueOf(item);
	}
}