/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Container;
import java.awt.Graphics;
import java.awt.Label;

/**
 * A tab used by <code>Tabs</code>.
 * The tab as a <code>BorderLayout</code> and the title's label is added to <code>NORTH</code>.
 * 
 * @author Michael Hedenus
 */
public class Tab extends Container
{
	private static final long serialVersionUID = 1798711327800804865L;

	private final Label title;

	public Tab(String name, String title)
	{
		setLayout(new BorderLayout());
		setName(name);
		this.title = new Label(title)
		{
			private static final long serialVersionUID = 1804066105650513894L;

			public void paint(Graphics g)
			{
				super.paint(g);
				g.setColor(getForeground());
				int y = getHeight() - 1;
				g.drawLine(0, y, getWidth(), y);
			}
		};
		this.title.setFont(UILayout.getInstance().getFont("Tab.titleFont"));
		this.add(this.title, BorderLayout.NORTH);
		setBackground(UILayout.getInstance().getColor("default.background"));
		setForeground(UILayout.getInstance().getColor("default.foreground"));
		setFont(UILayout.getInstance().getFont("default.font"));
	}
	
	/**
	 * Callback invoked when this tab has been selected.
	 */
	public void tabSelected()
	{
		//NOP
	}
	
	public Component getTitleComponent()
	{
		return title;
	}

	public void setTitle(String title)
	{
		this.title.setText(title);
	}
	
	public String getTitle()
	{
		return this.title.getText();
	}
}
