/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.awt.BorderLayout;
import java.awt.CardLayout;
import java.awt.Container;
import java.awt.Panel;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.List;

/**
 * A tabbed container.
 * 
 * @author Michael Hedenus
 */
public class Tabs extends Container
{
	private static final long serialVersionUID = -279474808253768132L;

	private ArrayList tabs = new ArrayList();
	private Panel cards;
	private CardLayout cardLayout;
	private ListSelection tabList;

	public Tabs()
	{
		setLayout(new BorderLayout());

		cardLayout = new CardLayout();
		cards = new Panel(cardLayout);
		this.add(cards, BorderLayout.CENTER);

		tabList = new ListSelection()
		{
			private static final long serialVersionUID = -2955134158475676309L;

			protected String toString(List list, Object item, int row, boolean selected)
			{
				Tab tab = (Tab)item;
				return tab.getTitle();
			}
		};
		tabList.setList(tabs);
		tabList.addActionListener(new ActionListener()
		{
			public void actionPerformed(ActionEvent e)
			{
				showTab((Tab)tabList.getSelectedItem());
			}		
		});
		
		this.add(tabList, BorderLayout.WEST);
	}
	
	public void setTabsEnabled(boolean b)
	{
		tabList.setEnabled(b);
	}
	
	public void showTab(Tab tab)
	{
		if(tabList.setSelectedItem(tab))
		{
			cardLayout.show(cards, tab.getName());
			tab.tabSelected();
		}
	}

	public void addTab(Tab tab)
	{
		cards.add(tab, tab.getName());
		tabs.add(tab);
	}
}
