/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilegui;

import java.awt.Color;
import java.awt.Component;
import java.awt.Font;
import java.awt.Graphics;
import java.util.Hashtable;

/**
 * Centralisation of UI layout settings.
 * 
 * @author Michael Hedenus
 */
public class UILayout extends Hashtable
{
	private static final long serialVersionUID = -8299175314789130174L;

	private static UILayout instance;

	public static synchronized UILayout getInstance()
	{
		if (instance == null)
		{
			instance = new UILayout();
		}

		return instance;
	}

	private UILayout()
	{
		this.put("default.font", new Font("SansSerif", Font.PLAIN, 10));
		this.put("default.background", Color.lightGray);
		this.put("default.foreground", Color.black);
		this.put("default.focus", Color.white);
		
		this.put("Bar.foreground", Color.red);
		this.put("Bar.background", Color.gray);
		
		this.put("ListSelection.selectionBackground", Color.red);
		this.put("ListSelection.selectionForeground", Color.white);
		this.put("ListSelection.selectionFont", deriveFromDefaultFont(Font.BOLD));
		
		this.put("TextPanel.foreground", Color.black);
		this.put("TextPanel.background", Color.white);
		
		this.put("Tab.titleFont", deriveFromDefaultFont(Font.ITALIC));
	}
	
	public Font deriveFromDefaultFont(int style)
	{
		Font f = getFont("default.font");
		return new Font(f.getName(), f.getStyle()|style, f.getSize());
	}

	public Color getColor(String key)
	{
		return (Color)get(key);
	}

	public Font getFont(String key)
	{
		return (Font)get(key);
	}
	
	public void paintFocusBorder(Component c, Graphics g)
	{
		if (c.hasFocus())
		{
			g.setColor(UILayout.getInstance().getColor("default.focus"));
			g.drawRect(0, 0, c.getWidth() - 1, c.getHeight() - 1);
		}
	}
}
