/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilexml;

/**
 * An XML item.
 * 
 * @author Michael Hedenus
 */
public abstract class Item
{
	/**
	 * The element name (including prefix and colon if any).
	 */
	final String name;
	
	/**
	 * The local name.
	 */
	String localName;
	
	/**
	 * The prefix.
	 */
	String namespacePrefix;
	
	/**
	 * The namespace URI.
	 */
	String namespaceURI;

	protected Item(String name)
	{
		this.name = name;
	}

	public String getLocalName()
	{
		return localName;
	}

	public String getName()
	{
		return name;
	}

	public String getNamespacePrefix()
	{
		return namespacePrefix;
	}

	public String getNamespaceURI()
	{
		return namespaceURI;
	}

	public boolean hasNamespace()
	{
		return namespaceURI != null;
	}
	
	public String getItemURI()
	{
		return (hasNamespace() ? (namespaceURI + localName) : name);
	}

	/**
	 * Returns true iff the localName and the namespaceURI match.
	 */
	public boolean equals(String localName, String namespaceURI)
	{
		return this.localName.equals(localName)
		&& ((this.namespaceURI == null && namespaceURI == null) || (this.namespaceURI != null && this.namespaceURI.equals(namespaceURI)));
	}
}
