/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.mobilexml;

import java.util.List;

/**
 * Interface for classes which wants to listen to events generated by the XMLParser.
 * 
 * @author Michael Hedenus
 */
public interface XMLParserEventListener
{
	/**
	 * Method called when an tag start is encountered.
	 * @param element the current element
	 * @param attributeList the list of <code>Attribute</code> objects (<b>Note:</b> the list is live!)
	 */
	public void elementBegin(Element element, List attributeList) throws XMLException;

	/**
	 * Method called when some plain text between two tags is encountered.
	 */
	public void text(String text) throws XMLException;

	/**
	 * The method called when a tag end is encountered.
	 */
	public void elementEnd(String tagName) throws XMLException;
}
