/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdf;

import de.hedenus.graph.Node;
import java.io.Serializable;

/**
 * Base type for resources, literals and blank nodes.
 * 
 * @author Michael Hedenus
 */
public abstract class RDFNode implements Node, Serializable, Comparable
{
	private final String id;

	protected RDFNode(String id)
	{
		if (id == null)
		{
			throw new IllegalArgumentException("id must not be null");
		}

		this.id = id;
	}

	public String id()
	{
		return id;
	}

	/**
	 * Returns <code>label()</code>.
	 */
	public String toString()
	{
		return label();
	}

	public abstract String label();

	/**
	 * Returns the this node's subject identifier.
	 */
	public abstract String about();

	public boolean equals(Object obj)
	{
		return compareTo(obj) == 0;
	}

	/**
	 * Two blank nodes are equal if their ids are equal.
	 */
	public int compareTo(Object obj)
	{
		if (this == obj)
		{
			return 0;
		}
		else
		{
			RDFNode that = (RDFNode)obj;
			return this.about().compareTo(that.about());
		}
	}
}
