/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdf;

public class StringUtil
{
	private StringUtil()
	{
		//NOP
	}

	public static String normalizeSpace(String s)
	{
		final int len = s.length();
		final StringBuffer b = new StringBuffer();

		for (int i = skipSpace(s, 0); i < len; i++)
		{
			final char c = s.charAt(i);
			if (c > ' ')
			{
				b.append(c);
			}
			else
			{
				i += skipSpace(s, i) - 1;
				if (i < len-1)
				{
					b.append(' ');
				}
			}
		}

		return b.toString();
	}

	private static final int skipSpace(String s, int offset)
	{
		final int len = s.length();

		int skipped = 0;
		for (int i = offset; i < len; i++)
		{
			final char c = s.charAt(i);
			if (c > ' ')
			{
				break;
			}
			else
			{
				skipped++;
			}
		}

		return skipped;
	}

	public static boolean isEmpty(String s)
	{
		boolean result = true;

		if (s != null)
		{
			final int len = s.length();
			for (int i = 0; i < len; i++)
			{
				if (s.charAt(i) > ' ') /* space */
				{
					result = false;
					break;
				}
			}
		}

		return result;
	}

	/**
	 * null is less than non-null
	 * @param s1
	 * @param s2
	 * @return
	 */
	public static int compare(String s1, String s2)
	{
		if (s1 == s2)
		{
			return 0;
		}

		if (s1 != null && s2 != null)
		{
			return s1.compareTo(s2);
		}

		if (s1 == null && s2 != null)
		{
			return -1;
		}

		if (s1 != null && s2 == null)
		{
			return +1;
		}

		// both null
		return 0;
	}
}
