/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdf;

import de.hedenus.www.URIReference;
import java.io.Serializable;

/**
 * A RDF <a href="http://www.w3.org/TR/rdf-concepts/#section-Graph-URIref">URI-reference node</a>.
 * 
 * @author Michael Hedenus
 */
public class URIRefNode extends RDFNode implements URIReference, Serializable
{
	private static final long serialVersionUID = -1250188697842443988L;

	private final String uri;

	protected URIRefNode(String uri, String id)
	{
		super(id);
		if (uri == null)
		{
			throw new IllegalArgumentException("URI must not be null");
		}

		this.uri = uri;
	}

	/**
	 * Returns the URI this resource referes to.
	 */
	public String getURI()
	{
		return uri;
	}

	/**
	 * Two Resources are equal if their URIs are equal.
	 */
	public boolean equals(Object obj)
	{
		if (this == obj)
		{
			return true;
		}

		if (obj != null && obj instanceof URIRefNode)
		{
			return this.uri.equals(((URIRefNode)obj).uri);
		}

		return false;
	}

	public int hashCode()
	{
		return uri.hashCode();
	}

	public String about()
	{
		return getURI();
	}

	public String label()
	{
		return "<" + getURI() + ">";
	}
}
