/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdf.serialize;

import java.util.HashMap;

import de.hedenus.rdf.BlankNode;
import de.hedenus.rdf.RDFException;
import de.hedenus.rdf.RDFGraph;
import de.hedenus.rdf.RDFNode;
import de.hedenus.rdf.Statement;

/**
 * A RDF event listener which add statements the a RDF graph. 
 * 
 * @author Michael Hedenus
 */
public class GraphBuilder implements RDFEventListener
{		
	private final HashMap blankNodeMapping = new HashMap();
	private final RDFGraph graph;
	
	private final int statementType;
	
	/**
	 * Creates a new graph builder for asserted statements.
	 */
	public GraphBuilder(RDFGraph graph)
	{
		this(graph, RDFGraph.STATEMENT_ASSERTED);
	}
	
	/**
	 * Creates a new graph builder for statements of the specified type.
	 */
	public GraphBuilder(RDFGraph graph, int statementType)
	{
		this.graph = graph;
		this.statementType = statementType;
	}
	
	public void newStatement(	String subject, int subjectType,
								String predicate,
								String object, int objectType, String datatype, String lang)
	{
		RDFNode subjectNode = createNode(subject, subjectType, datatype, lang);
		RDFNode objectNode = createNode(object, objectType, datatype, lang);
		
		Statement statement = graph.createStatement(subjectNode, predicate, objectNode, statementType);
	}

	private RDFNode createNode(String value, int type, String datatype, String lang)
	{
		RDFNode node;
		switch(type)
		{
			case RDFEventListener.NODETYPE_BLANK_NODE:
				// value = nodeID
				if (value != null)
				{
					//if nodeID is specified create a mapping of the nodeID to the blank node
					node = (BlankNode)blankNodeMapping.get(value);
					if (node == null)
					{
						node = graph.createBlankNode();
						blankNodeMapping.put(value, node);
					}
				}
				else
				{
					// no nodeID: new anonymous blank node
					node = graph.createBlankNode();
				}
				break;
				
			case RDFEventListener.NODETYPE_URIREF:
				// value = URI
				node = graph.createURIRefNode(value);
				break;
				
			case RDFEventListener.NODETYPE_LITERAL:
				// value = string
				node = graph.createLiteral(value, datatype, lang);
				break;
				
			default:
				throw new RDFException("Unknwon node type: "+type);
		}
		
		return node;
	}
}
