/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdf.serialize;

/**
 * RDF event listener.
 * 
 * @author Michael Hedenus
 */
public interface RDFEventListener
{
	/**
	 * Constant denoting a blank node.
	 */
	public static final int NODETYPE_BLANK_NODE = 0;
	
	/**
	 * Constant denoting an URI reference node.
	 */
	public static final int NODETYPE_URIREF = 1;
	
	/**
	 * Consant denoting a literal.
	 */
	public static final int NODETYPE_LITERAL = 2;
	
	/**
	 * Call-back invoked when a RDF parser parsed a new statement.
	 * @param subject the triple's subject
	 * @param subjectType the node type of the subject, either <code>NODETYPE_URIREF</code> or <code>NODETYPE_BLANK_NODE</code>
	 * @param predicate the triple's predicate
	 * @param object the triple's predicate
	 * @param objectType  the node type of the object, either <code>NODETYPE_URIREF</code>, <code>NODETYPE_BLANK_NODE</code> or <code>NODETYPE_LITERAL</code>
	 * @param datatype the datatype of the object (if it is a literal) or <code>null</code> 
	 * @param lang the language tag of the object (if it is a literal) or <code>null</code> 
	 */
	public void newStatement(	String subject, int subjectType,
								String predicate,
								String object, int objectType,
								String datatype, String lang);
}
