/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdf.serialize;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;

import de.hedenus.www.URIUtil;

/**
 * Base class for RDF parsers.
 * 
 * @author Michael Hedenus
 */
public abstract class RDFParser
{
	public abstract void parse(RDFEventListener rdfEventListener, InputStream in, String encoding, String documentBase) throws IOException;

	public void parse(RDFEventListener rdfEventListener, File file, String encoding) throws IOException
	{
		this.parse(rdfEventListener, file, encoding, URIUtil.toURI(file));
	}
	
	public void parse(RDFEventListener rdfEventListener, File file, String encoding, String documentBase) throws IOException
	{
		FileInputStream fin = null;
		try
		{
			fin = new FileInputStream(file);
			this.parse(rdfEventListener, fin, encoding, documentBase);
		}
		finally
		{
			if (fin != null)
			{
				fin.close();
			}
		}
	}

	public void parse(RDFEventListener rdfEventListener, URL url) throws IOException
	{
		InputStream in = null;
		try
		{
			URLConnection connection = url.openConnection();
			String encoding = connection.getContentEncoding();
			//System.out.println("RDFParser: encoding: " + encoding);
			
			in = connection.getInputStream();
			this.parse(rdfEventListener, in, encoding, url.toExternalForm());
		}
		finally
		{
			if (in != null)
			{
				in.close();
			}
		}
	}
}
