/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdf.serialize;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

import de.hedenus.rdf.RDFGraph;

/**
 * Base class for RDF serializers.
 * 
 * @author Michael Hedenus
 */
public abstract class RDFSerializer
{
	public abstract void serialize(RDFGraph graph, OutputStream outputStream) throws IOException;

	public void serialize(RDFGraph graph, File file) throws IOException
	{
		OutputStream outputStream = null;
		try
		{
			outputStream = new FileOutputStream(file);
			serialize(graph, outputStream);
		}
		finally
		{
			if (outputStream != null)
			{
				outputStream.close();
			}
		}
	}
}
