/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdfschema;

import java.util.ArrayList;
import java.util.List;

import de.hedenus.rdf.RDFException;
import de.hedenus.www.Namespaces;

/**
 * Implementation of rdfs:Container.
 * 
 * @author Michael Hedenus
 */
public abstract class ContainerImpl extends ResourceImpl implements Container
{
	//	 cache the properties rdf:_1 .. rdf:_10
	private static final String[] liProperties = new String[11];
	static
	{
		for (int i = 1; i < liProperties.length; i++)
		{
			liProperties[i] = Namespaces.RDF + "_" + i;
		}
	}

	private String liProperty(int n)
	{
		if (n <= 0)
		{
			throw new RDFException("Value of container membership property must be greater than 0.");
		}

		return n < liProperties.length ? liProperties[n] : Namespaces.RDF + "_" + n;
	}

	public Resource li(int n)
	{
		return getProperty(liProperty(n));
	}

	public Object li(int n, String datatypeURI)
	{
		return getProperty(liProperty(n), datatypeURI);
	}

	public List toList()
	{
		ArrayList list = new ArrayList();
		Resource li = null;
		for (int n = 1; (li = li(n)) != null; n++)
		{
			list.add(li);
		}
		return list;
	}

	public List toList(String datatypeURI)
	{
		ArrayList list = new ArrayList();
		Object li = null;
		for (int n = 1; (li = li(n, datatypeURI)) != null; n++)
		{
			list.add(li);
		}
		return list;
	}
}
