/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdfschema;

import java.util.ArrayList;
import java.util.Iterator;

import de.hedenus.rdf.GraphListener;
import de.hedenus.rdf.RDFGraph;
import de.hedenus.rdf.Statement;

/**
 * An inference engine.
 * 
 * @author Michael Hedenus
 */
public class InferenceEngine implements GraphListener
{
	private final RDFDatabinding databinding;
	private java.util.List rules = new ArrayList();

	public InferenceEngine(RDFDatabinding databinding)
	{
		this.databinding = databinding;
	}

	public void addRule(Rule rule)
	{
		rules.add(rule);
	}

	private int newStatements = 0;
	private ArrayList statements;
	private Rule currentRule;

	public void statementCreated(RDFGraph graph, Statement newStatement)
	{
		//System.out.println(currentRule.getName() + ": " + newStatement);

		// add new statements to list
		statements.add(newStatement);
		newStatements++;
	}

	public void inferAsMuchAsPossible()
	{
		long t0 = System.currentTimeMillis();

		final int maxIterations = 3;
		newStatements = 0;
		int i = 0;

		try
		{
			databinding.getGraph().addGraphListener(this);

			// get statements as list
			statements = new ArrayList((int)(1.1 * databinding.getGraph().arcs().size()));
			for (Iterator s = databinding.getGraph().arcs().iterator(); s.hasNext();)
			{
				statements.add(s.next());
			}

			//
			// brute force forward infering
			//
			for (; i < maxIterations; i++)
			{
				// for each statement
				for (int s = 0; s < statements.size(); s++)
				{
					Statement statement = (Statement)statements.get(s);

					// for each rule
					for (int r = 0; r < rules.size(); r++)
					{
						currentRule = (Rule)rules.get(r);

						currentRule.execute(databinding, statement);
					}
				}

				// if new statements have been infered, iterate
				// else finish
				if (newStatements == 0)
				{
					break;
				}
				else
				{
					newStatements = 0;
				}
			}
		}
		finally
		{
			databinding.getGraph().removeGraphListener(this);
			statements.clear();
			statements = null;
		}

		System.out.println("Done with " + (i) + " iterations in " + (System.currentTimeMillis() - t0) + "ms.");
	}
}
