/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdfschema;

import java.util.Locale;

import de.hedenus.rdf.RDFNode;

/**
 * Base implementation of a RDF bound Java object.
 * 
 * @author Michael Hedenus
 */
public class ResourceImpl implements Resource
{
	private RDFDatabinding binding;
	private RDFNode node;

	protected ResourceImpl()
	{
		//NOP
	}
	
	protected void init(RDFDatabinding binding, RDFNode node)
	{
		this.binding = binding;
		this.node = node;
	}

	protected RDFDatabinding binding()
	{
		return binding;
	}

	/**
	 * Returns the bound RDF node.
	 */
	protected RDFNode node()
	{
		return node;
	}
	
	public String about()
	{
		return node.about();
	}
	
	public String toString()
	{
		return about();
	}

	public Object getProperty(String propertyURI, String datatypeURI)
	{
		return binding().getPropertyValue(about(), propertyURI, datatypeURI);
	}
	
	public String getProperty(String propertyURI, Locale locale)
	{
		return binding().getPropertyValue(about(), propertyURI, locale);
	}

	public Resource getProperty(String propertyURI)
	{
		return binding().getPropertyValue(about(), propertyURI);
	}

	public Resource[] getProperties(String propertyURI)
	{
		return binding().getPropertyValues(about(), propertyURI);
	}
}
