/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdfschema.rules;

import java.util.ArrayList;

import de.hedenus.rdf.RDFGraph;
import de.hedenus.rdf.Statement;
import de.hedenus.rdfschema.RDFDatabinding;
import de.hedenus.rdfschema.Rule;

/**
 * Base class for rule implementations.
 * 
 * @author Michael Hedenus
 */
public abstract class AbstractRule implements Rule
{
	private final String name;
	
	protected static ArrayList tempResult = new ArrayList();
	
	protected AbstractRule(String name)
	{
		this.name = name;
	}
	
	public String getName()
	{
		return name;
	}

	public void execute(RDFDatabinding databinding, Statement statement)
	{
		try
		{
			execute(databinding, databinding.getGraph(), statement);
		}
		finally
		{
			tempResult.clear();
		}
	}

	protected abstract void execute(RDFDatabinding databinding, RDFGraph graph, Statement statement);
}
