/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdfschema.rules;

import de.hedenus.rdf.RDFGraph;
import de.hedenus.rdf.RDFNode;
import de.hedenus.rdf.Statement;
import de.hedenus.rdfschema.RDFDatabinding;
import de.hedenus.rdfschema.RDFSchemaConstants;

/**
 * Property propagation through rdfs:subPropertyOf.
 * 
 * @author Michael Hedenus
 */
public class PropertyPropagationRule extends AbstractRule
{
	public PropertyPropagationRule()
	{
		super("Property Propagation");
	}

	/**
	 * x P y  and P rdfs:subPropertyOf Q => x Q y.
	 */
	public void execute(RDFDatabinding databinding, RDFGraph graph, Statement statement)
	{
		RDFNode subject = statement.getSubject();
		String propertyURI = statement.getPredicate();
		RDFNode object = statement.getObject();

		graph.queryStatement(propertyURI, RDFSchemaConstants.SUBPROPERTYOF_URI, "*", tempResult);

		for (int i = 0; i < tempResult.size(); i++)
		{
			String parentPropertyURI = ((Statement)tempResult.get(i)).getObject().about();

			graph.createStatement(//
					subject, //
					parentPropertyURI, //
					object, //
					RDFGraph.STATEMENT_INFERED);
		}
	}
}