/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdfschema.rules;

import de.hedenus.rdf.RDFConstants;
import de.hedenus.rdf.RDFGraph;
import de.hedenus.rdf.RDFNode;
import de.hedenus.rdf.Statement;
import de.hedenus.rdf.URIRefNode;
import de.hedenus.rdfschema.RDFDatabinding;
import de.hedenus.rdfschema.RDFSchemaConstants;

/**
 * An URI used in a statement as subject defines a resource.
 * 
 * @author Michael Hedenus
 */
public class ResourceRule extends AbstractRule
{
	public ResourceRule()
	{
		super("Resource");
	}

	/**
	 * ?a ?b ?c and ?a URI => ?a rdf:type rdfs:Resource.
	 */
	public void execute(RDFDatabinding databinding, RDFGraph graph, Statement statement)
	{
		RDFNode subject = statement.getSubject();
		
		if(subject instanceof URIRefNode)
		{
			graph.createStatement( //
					subject,
					RDFConstants.TYPE_URI, //
					graph.createURIRefNode(RDFSchemaConstants.RESOURCE_URI), //
					RDFGraph.STATEMENT_INFERED);
		}
	}

}
