/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.rdfschema.rules;

import de.hedenus.rdf.RDFConstants;
import de.hedenus.rdf.RDFGraph;
import de.hedenus.rdf.RDFNode;
import de.hedenus.rdf.Statement;
import de.hedenus.rdf.URIRefNode;
import de.hedenus.rdfschema.RDFDatabinding;
import de.hedenus.rdfschema.RDFSchemaConstants;

/**
 * Type propagation through rdfs:subClassOf.
 * 
 * @author Michael Hedenus
 */
public class TypePropagationRule extends AbstractRule
{
	public TypePropagationRule()
	{
		super("Type Propagation");
	}

	/**
	 * ?a rdf:type A and A rdfs:subClassOf B => ?a rdf:type B.
	 */
	public void execute(RDFDatabinding databinding, RDFGraph graph, Statement statement)
	{
		if (statement.getPredicate().equals(RDFConstants.TYPE_URI) && statement.getObject() instanceof URIRefNode)
		{
			String classURI = statement.getObject().about();

			graph.queryStatement(classURI, RDFSchemaConstants.SUBCLASSOF_URI, "*", tempResult);

			for (int i = 0; i < tempResult.size(); i++)
			{
				RDFNode parentClass = ((Statement)tempResult.get(i)).getObject();
				
				graph.createStatement(//
						statement.getSubject(),
						RDFConstants.TYPE_URI, //
						parentClass, //
						RDFGraph.STATEMENT_INFERED
						);
			}
		}
	}
}
