/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.www;

/**
 * Defines common namespace URIs.
 * 
 * @author Michael Hedenus
 */
public class Namespaces
{
	private Namespaces()
	{
		//NOP
	}

	 /**
     * <p>The official XML Namespace name URI.</p>
     *
     * <p>Defined by the XML specification to be
     * "<code>http://www.w3.org/XML/1998/namespace</code>".</p>
     *
     * @see <a
     * href="http://www.w3.org/TR/REC-xml-names/#ns-qualnames">
     * Namespaces in XML, 3. Qualified Names</a>
     */
	public static final String XMLNS = "http://www.w3.org/XML/1998/namespace";
	
	 /**
     * <p>The official XML attribute used for specifying XML Namespace
     * declarations Namespace name URI.</p>
     *
     * <p>Defined by the XML specification to be
     * "<code>http://www.w3.org/2000/xmlns/</code>".</p>
     *
     * @see <a
     * href="http://www.w3.org/TR/REC-xml-names/#ns-qualnames">
     * Namespaces in XML, 3. Qualified Names</a>
     * @see <a
     * href="http://www.w3.org/XML/xml-names-19990114-errata/">
     * Namespaces in XML Errata</a>
     */
    public static final String XMLNS_ATTRIBUTE = "http://www.w3.org/2000/xmlns/";
    
    /**
     * <p>Namespace URI to use to represent that there is no Namespace.</p>
     *
     * <p>Defined by the Namespace specification to be "".</p>
     *
     * @see <a href="http://www.w3.org/TR/REC-xml-names/#defaulting">
     * Namespaces in XML, 5.2 Namespace Defaulting</a>
     */
    public static final String NO_NAMESPACE = "";
	
	public static final String RDF = "http://www.w3.org/1999/02/22-rdf-syntax-ns#";

	public static final String RDFSCHEMA = "http://www.w3.org/2000/01/rdf-schema#";

	public static final String OWL = "http://www.w3.org/2002/07/owl#";
	
	public static final String XMLSCHEMA = "http://www.w3.org/2001/XMLSchema#";
		
	public static final String WGS84_POS = "http://www.w3.org/2003/01/geo/wgs84_pos#";
	
	public static final String DUBLINCORE11 = "http://purl.org/dc/elements/1.1/";
	
	public static final String RSS10 = "http://purl.org/rss/1.0/";

	public final static String HEDENUS_ONTOLOGIE = "http://www.hedenus.de/Ontologie/";	
}