/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.xmltypes;

import de.hedenus.xmltypes.impl.TypeFactoryImpl;

/**
 * Factory for the implementation of the XML typing system. 
 * 
 * @author Michael Hedenus
 */
public abstract class TypeFactory
{
	public static TypeFactory newInstance() throws TypeFactoryConfigurationException
	{
		return new TypeFactoryImpl();
	}

	/**
	 * Returns a type according to its literal specification.
	 */
	public abstract Type getType(String spec) throws TypeException;

	/**
	 * Helper method for development.
	 */
	public static final void printTypeHierarchy(Type type)
	{
		printTypeHierarchy(type, "");
	}

	private static final void printTypeHierarchy(Type type, String indent)
	{
		System.out.println(indent + type + " (" + type.getClass().getName() + ")");
		Type[] baseTypes = type.getBaseTypes();
		if (baseTypes != null)
		{
			for (int i = 0; i < baseTypes.length; i++)
			{
				printTypeHierarchy(baseTypes[i], indent + " ");
			}
		}
	}
}
