/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.xmltypes.impl;

import de.hedenus.xmltypes.Type;
import de.hedenus.xmltypes.TypeException;

/**
 * Basic <code>Type</code> implementation.
 * 
 * @author Michael Hedenus
 */
public abstract class AbstractTypeImpl implements Type
{
	protected final TypeFactoryImpl typeFactory;
	protected final String name;
	protected final Type[] baseTypes;

	protected AbstractTypeImpl(TypeFactoryImpl typeFactory, String name, Type[] baseTypes)
	{
		this.typeFactory = typeFactory;
		this.name = getTypeSystem() + "#" + name;
		this.baseTypes = baseTypes;
	}

	public String getName()
	{
		return name;
	}
	
	public String toString()
	{
		return name;
	}

	public Type[] getBaseTypes()
	{
		return baseTypes;
	}

	public String toLiteral(Object value) throws TypeException
	{
		checkNull(value);
		return String.valueOf(value);
	}

	protected void checkNull(Object val)
	{
		if (val == null)
		{
			throw new IllegalArgumentException("argument must not be null");
		}
	}
}
