/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.xmltypes.impl;

import de.hedenus.xmltypes.Type;
import de.hedenus.xmltypes.TypeException;

/**
 * Boolean type.
 * 
 * @author Michael Hedenus
 */
public class BooleanType extends BuiltInPrimitiveType
{
	public BooleanType(TypeFactoryImpl typeFactory)
	{
		super(typeFactory, "boolean", new Type[] { typeFactory.getBuiltInW3SchemaType("anySimpleType") });
	}

	public Object parse(String literal) throws TypeException
	{
		checkNull(literal);
		if ("true".equals(literal) || "1".equals(literal))
		{
			return Boolean.TRUE;
		}
		else if ("false".equals(literal) || "0".equals(literal))
		{
			return Boolean.FALSE;
		}
		else
		{
			throw new TypeException("boolean lexical space is {0, 1, true, false}");
		}
	}

	public boolean validate(Object value)
	{
		checkNull(value);
		return value instanceof Boolean;
	}

	public Class getRepresentationClass()
	{
		return Boolean.class;
	}
}
