/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.xmltypes.impl;

import java.math.BigDecimal;

import de.hedenus.xmltypes.Type;
import de.hedenus.xmltypes.TypeException;

/**
 * Decimal type.
 * 
 * @author Michael Hedenus
 */
public class DecimalType extends BuiltInPrimitiveType
{
	protected DecimalType(TypeFactoryImpl typeFactory)
	{
		super(typeFactory, "decimal", new Type[] { typeFactory.getBuiltInW3SchemaType("anySimpleType") });
	}

	public Object parse(String literal) throws TypeException
	{
		checkNull(literal);
		return new BigDecimal(literal);
	}

	public boolean validate(Object value)
	{
		checkNull(value);
		return value instanceof Number;
	}
	
	public Class getRepresentationClass()
	{
		return BigDecimal.class;
	}
}
