/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package de.hedenus.xmltypes.impl;

import java.util.HashMap;

import de.hedenus.xmltypes.Type;
import de.hedenus.xmltypes.TypeException;
import de.hedenus.xmltypes.TypeFactory;

/**
 * Basic implementation of <code>TypeFactory</code>.
 * 
 * @author Michael Hedenus
 */
public class TypeFactoryImpl extends TypeFactory
{
	/**
	 * Built-in simple types.
	 */
	private final HashMap types = new HashMap();

	public TypeFactoryImpl()
	{
		types.put("http://www.w3.org/2001/XMLSchema#anyType", new AnyType(this));
		types.put("http://www.w3.org/2001/XMLSchema#anySimpleType", new AnySimpleType(this));
		types.put("http://www.w3.org/2001/XMLSchema#string", new StringType(this));
		types.put("http://www.w3.org/2001/XMLSchema#anyURI", new AnyURIType(this));
		types.put("http://www.w3.org/2001/XMLSchema#boolean", new BooleanType(this));
		types.put("http://www.w3.org/2001/XMLSchema#double", new DoubleType(this));
		types.put("http://www.w3.org/2001/XMLSchema#float", new FloatType(this));
		types.put("http://www.w3.org/2001/XMLSchema#decimal", new DecimalType(this));
		types.put("http://www.w3.org/2001/XMLSchema#integer", new IntegerType(this));
		types.put("http://www.w3.org/2001/XMLSchema#long", new LongType(this));
		types.put("http://www.w3.org/2001/XMLSchema#int", new IntType(this));
		types.put("http://www.w3.org/2001/XMLSchema#date", new DateType(this));
		types.put("http://www.w3.org/2001/XMLSchema#dateTime", new DateTimeType(this));
		types.put("http://www.w3.org/1999/02/22-rdf-syntax-ns#XMLLiteral", new XMLLiteral(this));
	}

	public Type getType(String spec) throws TypeException
	{
		Type t = (Type)types.get(spec);
		if (t == null)
		{
			throw new TypeException("No type available for " + spec + ".");
		}
		return t;
	}

	W3SchemaType getBuiltInW3SchemaType(String name)
	{
		return (W3SchemaType)types.get("http://www.w3.org/2001/XMLSchema#" + name);
	}

	/*
	 public static void main(String[] args) throws Exception
	 {
	 TypeFactory typeFactory = TypeFactory.newInstance();
	 
	 Type type1 = typeFactory.getType("http://www.w3.org/2001/XMLSchema#int");
	 TypeFactory.printTypeHierarchy(type1);
	 
	 Type type2 = typeFactory.getType("http://www.w3.org/2001/XMLSchema#dateTime");
	 TypeFactory.printTypeHierarchy(type2);
	 }
	 */
}
