/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package examples;

import java.net.URL;
import java.util.Locale;

import de.hedenus.rdfschema.RDFDatabinding;
import de.hedenus.rdfschema.Resource;
import de.hedenus.www.Namespaces;
import de.hedenus.xmltypes.date.DateTime;

/**
 * Example 4: RDF Schema.
 * 
 * @author Michael Hedenus
 */
public class Example4
{
	public static void main(String[] args) throws Exception
	{
		// a new databinding (includes the graph)
		RDFDatabinding dataBinding = new RDFDatabinding();

		// parse the RDF file
		dataBinding.parse(new URL("http://www.hedenus.de/rdf/example4.rdf"));

		// get a resource
		Resource example4 = dataBinding.getResource("http://www.hedenus.de/rdf/example4.rdf");
		
		// list all dc:description properties
		Resource[] hellos = example4.getProperties(Namespaces.DUBLINCORE11 + "description");
		for (int i = 0; i < hellos.length; i++)
		{
			System.out.println(hellos[i]);
		}

		// list only (first) french dc:description
		System.out.println(example4.getProperty(Namespaces.DUBLINCORE11 + "description", (Locale)null));
		
		// get a typed literal
		DateTime dateTime = (DateTime)example4.getProperty(Namespaces.DUBLINCORE11 + "date", Namespaces.XMLSCHEMA + "dateTime");
		System.out.println(dateTime.toDate());
	}
}
