/*****************************************************************************
 *  Copyright 2008 Michael Hedenus                                           *
 *                                                                           *
 *  Licensed under the Apache License, Version 2.0 (the "License");          *
 *  you may not use this file except in compliance with the License.         *
 *  You may obtain a copy of the License at                                  *
 *                                                                           *
 *      http://www.apache.org/licenses/LICENSE-2.0                           *
 *                                                                           *
 *  Unless required by applicable law or agreed to in writing, software      *
 *  distributed under the License is distributed on an "AS IS" BASIS,        *
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. *
 *  See the License for the specific language governing permissions and      *
 *  limitations under the License.                                           *
 *****************************************************************************/
package examples;

import java.net.URL;
import java.util.Iterator;

import de.hedenus.mobilerss.Channel;
import de.hedenus.mobilerss.Item;
import de.hedenus.rdfschema.RDFDatabinding;
import de.hedenus.www.Namespaces;
import de.hedenus.xmltypes.date.Date;

/**
 * Example 5: RDF Schema databinding.
 * 
 * @author Michael Hedenus
 */
public class Example5
{
	public static void main(String[] args) throws Exception
	{
		// a new databinding (includes the graph)
		// type mappings will be loaded from 'rdfschema/typemapping'
		RDFDatabinding dataBinding = new RDFDatabinding();

		// parse a RSS resource
		String home = "http://www.w3.org/2000/08/w3c-synd/home.rss";
		dataBinding.parse(new URL(home));

		// get the channel instance
		// (it is assumed that the channel URI is the same as the resource URL)
		Channel channel = (Channel)dataBinding.getResource(home);

		// the items are listed in form of rdf:Seq
		for (Iterator i = channel.items().iterator(); i.hasNext();)
		{
			// print next item
			Item item = (Item)i.next();
			String title = item.getTitle();
			System.out.print(title);

			// lookup an optional date information
			Date date = (Date)item.getProperty(Namespaces.DUBLINCORE11 + "date", Namespaces.XMLSCHEMA + "date");
			if (date != null)
			{
				System.out.print(" (" + date.toString() + ")");
			}

			System.out.println();
		}
	}
}
